import { OnInit, ElementRef, Renderer2, EventEmitter, OnDestroy, OnChanges, NgZone, SimpleChanges } from '@angular/core';
import { Subject, ReplaySubject } from 'rxjs';
import { DraggableHelper } from './draggable-helper.provider';
export interface Coordinates {
    x: number;
    y: number;
}
export interface DragAxis {
    x: boolean;
    y: boolean;
}
export interface SnapGrid {
    x?: number;
    y?: number;
}
export interface DragStart {
    cancelDrag$: ReplaySubject<void>;
}
export interface DragEnd extends Coordinates {
    dragCancelled: boolean;
}
export declare type ValidateDrag = (coordinates: Coordinates) => boolean;
export interface PointerEvent {
    clientX: number;
    clientY: number;
    event: MouseEvent | TouchEvent;
}
export declare class DraggableDirective implements OnInit, OnChanges, OnDestroy {
    private element;
    private renderer;
    private draggableHelper;
    private zone;
    private document;
    /**
     * an object of data you can pass to the drop event
     */
    dropData: any;
    /**
     * The axis along which the element is draggable
     */
    dragAxis: DragAxis;
    /**
     * Snap all drags to an x / y grid
     */
    dragSnapGrid: SnapGrid;
    /**
     * Show a ghost element that shows the drag when dragging
     */
    ghostDragEnabled: boolean;
    /**
     * Allow custom behaviour to control when the element is dragged
     */
    validateDrag: ValidateDrag;
    /**
     * The cursor to use when dragging the element
     */
    dragCursor: string;
    /**
     * The css class to apply when the element is being dragged
     */
    dragActiveClass: string;
    /**
     * The element the ghost element will be appended to. Default is next to the dragged element
     */
    ghostElementAppendTo: HTMLElement;
    /**
     * Called when the element can be dragged along one axis and has the mouse or pointer device pressed on it
     */
    dragPointerDown: EventEmitter<Coordinates>;
    /**
     * Called when the element has started to be dragged.
     * Only called after at least one mouse or touch move event.
     * If you call $event.cancelDrag$.emit() it will cancel the current drag
     */
    dragStart: EventEmitter<DragStart>;
    /**
     * Called when the element is being dragged
     */
    dragging: EventEmitter<Coordinates>;
    /**
     * Called after the element is dragged
     */
    dragEnd: EventEmitter<DragEnd>;
    /**
     * @hidden
     */
    pointerDown: Subject<PointerEvent>;
    /**
     * @hidden
     */
    pointerMove: Subject<PointerEvent>;
    /**
     * @hidden
     */
    pointerUp: Subject<PointerEvent>;
    private eventListenerSubscriptions;
    private ghostElement;
    /**
     * @hidden
     */
    constructor(element: ElementRef<HTMLElement>, renderer: Renderer2, draggableHelper: DraggableHelper, zone: NgZone, document: any);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private checkEventListeners();
    private onMouseDown(event);
    private onMouseUp(event);
    private onTouchStart(event);
    private onTouchEnd(event);
    private onMouseEnter();
    private onMouseLeave();
    private canDrag();
    private setCursor(value);
    private unsubscribeEventListeners();
    private setElementStyles(element, styles);
}
